==> kp_imc23-0.11.tar.gz: kp_imc23-0.11/kp_imc23/preprocessing/main.py <==
import argparse
import os
import pickle

from typing import Any, Dict, Tuple

import numpy as np
from kp_imc23.config.paths import DataPaths
from .rotate import rotate_images 
from .pairs import compute_pairs 
from .crop import crop_images 
from src.matching.loftr import loftr
from src.matching.superglue import superglue
from .utils import concat_keypoints, build_superlist



def preprocess(
    paths: DataPaths,
    args: argparse.Namespace
) -> Tuple[Dict[str, Any], bool]:
    """Preprocess images and output rotated images, and computed pairs.

    Args:s
        paths (DataPaths): contains all defined paths for the computation results.
        args (argparse.Namespace): Arguments.
    """

    image_list = os.listdir(paths.input_dir_images)

    # rotate images
    rotate_images(paths.input_dir_images, image_list, paths.rotated_image_dir, paths.rotation_model_weights)

    # compute pairs 
    compute_pairs(paths.rotated_image_dir, image_list, paths.features_retrieval, paths.pairs_path)

    # TODO: run in parallel
    # extract important keypoints 
    superglue(paths.rotated_image_dir,paths.pairs_path, paths.superglue_keypoints_pickle)
    loftr(paths.rotated_image_dir,paths.pairs_path ,paths.loftr_model_weights, paths.loftr_keypoints_pickle)
    
    # concat important keypoints
    keypoints = concat_keypoints(paths.superglue_keypoints_pickle,paths.loftr_keypoints_pickle)

    # crop images 
    crop_images(paths.rotated_image_dir, paths.pairs_path, paths.cropped_image_dir,keypoints)

    # build superlist
    superlist = build_superlist(keypoints)

==> kp_imc23-0.13.tar.gz: kp_imc23-0.13/kp_imc23/preprocessing/main.py <==
import argparse
import os
import pickle

from typing import Any, Dict, Tuple

import numpy as np
from kp_imc23.config.paths import DataPaths
from .rotate import rotate_images 
from .pairs import compute_pairs 
from .crop import crop_images 
from kp_imc23.matching.loftr import loftr
from kp_imc23.matching.superglue import superglue
from .utils import concat_keypoints, build_superlist



def preprocess(
    paths: DataPaths,
    args: argparse.Namespace
) -> Tuple[Dict[str, Any], bool]:
    """Preprocess images and output rotated images, and computed pairs.

    Args:s
        paths (DataPaths): contains all defined paths for the computation results.
        args (argparse.Namespace): Arguments.
    """

    image_list = os.listdir(paths.input_dir_images)

    # rotate images
    rotate_images(paths.input_dir_images, image_list, paths.rotated_image_dir, paths.rotation_model_weights)

    # compute pairs 
    compute_pairs(paths.rotated_image_dir, image_list, paths.features_retrieval, paths.pairs_path)

    # TODO: run in parallel
    # extract important keypoints 
    superglue(paths.rotated_image_dir,paths.pairs_path, paths.superglue_keypoints_pickle)
    loftr(paths.rotated_image_dir,paths.pairs_path ,paths.loftr_model_weights, paths.loftr_keypoints_pickle)
    
    # concat important keypoints
    keypoints = concat_keypoints(paths.superglue_keypoints_pickle,paths.loftr_keypoints_pickle)

    # crop images 
    crop_images(paths.rotated_image_dir, paths.pairs_path, paths.cropped_image_dir,keypoints)

    # build superlist
    superlist = build_superlist(keypoints)
